#include <SPI.h>

const int Connect = 8;
const int onRelay = 9;
int val = 0;

const int LowPin = 2;
const int MediumPin = 3;
const int HighPin = 4;
const int FullPin = 5;
const int Fulldischarge = A3;

const int upButton = 7;
const int downButton = 6;
int valUp; 
int valDown; 
byte POT = 0;
const int slaveSelectPin = 10;


const int analogPin = 1; // Use channel 0 ADC
int readBatt = 0;  // Read batt variable
float voltage = 0;
float realBatt = 0;

const int tempPin = 4;
int tempValue = 0;
const int onFan = A5;


void setup()
{
  Serial.begin(9600);
  pinMode(onFan,OUTPUT);
  pinMode(Connect,INPUT);
  pinMode(onRelay,OUTPUT);
  pinMode(upButton,INPUT);
  pinMode(downButton,INPUT);
  pinMode(slaveSelectPin,OUTPUT);
  pinMode(LowPin,OUTPUT);
  pinMode(MediumPin,OUTPUT);
  pinMode(HighPin,OUTPUT);
  pinMode(FullPin,OUTPUT);
  pinMode(Fulldischarge,OUTPUT);
  SPI.begin();
//***************** Set volume to Zero *************// 
  digitalWrite(slaveSelectPin,LOW);
  //Send in the address and value via SPI:
  SPI.transfer(0x11);
  SPI.transfer(0);
  //talk the CS Pin HIGH to de-select the chip:
  digitalWrite(slaveSelectPin,HIGH);
  
}
//************ END OF SETUP ********************//


void loop()
{
  
  BattConnect();
  delay(50);
  ReadBatt();
  currentADJ();
  TempCheck();

}
//************END *************//
 
  
//*************** Temperature and Fan ******************//
void TempCheck()
{
 tempValue = analogRead(tempPin);
  Serial.print("Temp=");
  Serial.println(tempValue);
  delay(100);
  
  if(tempValue >= 600)
  {
    digitalWrite(onFan,HIGH);
  } 
  else
  {
   digitalWrite(onFan,LOW);
  } 
}  
//**************** Digital Volume control ********************************//
void currentADJ()
{
  valUp = digitalRead(upButton);
  valDown = digitalRead(downButton);
  if(valUp == LOW && POT < 255)
  {
    POT=POT+4;
    digitalPotWrite(0x11,POT);
    delay(10);
  }
  else if(valDown == LOW && POT > 0)
  {
    POT=POT-4;
    digitalPotWrite(0x11,POT);
    delay(10);
  }
  
  Serial.print("Volume level =");
  Serial.println(POT);
  delay(10);
}  
//**************** Move value to MCP41010 **********************//
void digitalPotWrite(int address, int value)
{
  //talk the CS pin LOW to select the chip:
  digitalWrite(slaveSelectPin,LOW);
  //Send in the address and value via SPI:
  SPI.transfer(address);
  SPI.transfer(value);
  //talk the CS Pin HIGH to de-select the chip:
  digitalWrite(slaveSelectPin,HIGH);
}

//*************** Check battery polarity ***********************//
void BattConnect()
{
   val = digitalRead(Connect);
  if (val == LOW)
  {
    Serial.println("PIN 8 = LOW");
    digitalWrite(onRelay, HIGH);
  }
  else {
    digitalWrite(onRelay, LOW);
    Serial.println(" PIN 8 = HIGH");
  } 
}

//***************** Test battery voltage ******************************//
void ReadBatt()
{
readBatt = analogRead(analogPin); 
  voltage =readBatt*0.004882812 ; // 5V/1024
  realBatt = (20*voltage)/5;// convertion to real voltage
  Serial.print("Batt ADC Level=");
  Serial.println(readBatt);
  Serial.print("Voltage on ADC Pin=");
  Serial.println(voltage);
  Serial.print("Real Battery =");
  Serial.println(realBatt);
  delay(500);
  
  if(readBatt == 0) // Full dischage
  {
    
    digitalWrite(Fulldischarge,LOW);   
    digitalWrite(LowPin,LOW);
    digitalWrite(MediumPin,LOW);
    digitalWrite(HighPin,LOW);
    digitalWrite(FullPin,LOW);
        
  }
  
 else if(readBatt < 593) // Full dischage
  {
   
    digitalWrite(Fulldischarge,HIGH);
    digitalWrite(LowPin,LOW);
    digitalWrite(MediumPin,LOW);
    digitalWrite(HighPin,LOW);
    digitalWrite(FullPin,LOW);
    digitalWrite(slaveSelectPin,LOW);
  
  //Send in the address and value via SPI:
  SPI.transfer(0x11);
  SPI.transfer(0);
  //talk the CS Pin HIGH to de-select the chip:
  digitalWrite(slaveSelectPin,HIGH);
   
  }
    
   else if(readBatt >=593 && readBatt < 617) // 20% Level 
  {
    digitalWrite(Fulldischarge,LOW);   
    digitalWrite(LowPin,HIGH);
    delay(10);
    digitalWrite(LowPin,LOW);
    delay(10);
    digitalWrite(MediumPin,LOW);
    digitalWrite(HighPin,LOW);
    digitalWrite(FullPin,LOW);
  }
  else if(readBatt >= 617 && readBatt < 636 ) // 50% Level
  {
   digitalWrite(Fulldischarge,LOW);   
   digitalWrite(LowPin,HIGH);
   digitalWrite(MediumPin,HIGH);
   digitalWrite(HighPin,LOW);
   digitalWrite(FullPin,LOW);
  } 
  else if (readBatt >= 636 && readBatt < 650) // 80% Level
  {
   digitalWrite(Fulldischarge,LOW);   
   digitalWrite(LowPin,HIGH);
   digitalWrite(MediumPin,HIGH);
   digitalWrite(HighPin,HIGH);
   digitalWrite(FullPin,LOW);
  }
  else if (readBatt >= 650) // 100% Up Level
  {
   digitalWrite(Fulldischarge,LOW);   
   digitalWrite(LowPin,HIGH);
   digitalWrite(MediumPin,HIGH);
   digitalWrite(HighPin,HIGH);
   digitalWrite(FullPin,HIGH);
  }
}
//******************************************************//
